@@ -9,7 +9,7 @@ use Mojo::Util;
 
 use constant LAZY => $ENV{MOJO_WEBPACK_LAZY} ? 1 : 0;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 sub assets_dir { shift->{assets_dir} }
 sub out_dir    { shift->{out_dir} }
@@ -52,7 +52,7 @@ sub _after_static_hook {
     $p->to_string;
   };
 
-  $c->res->headers->cache_control('max-age=86400') if 0 == index $c->req->url->path, $asset_path;
+  $c->res->headers->cache_control(LAZY ? 'no-cache' : 'max-age=86400') if 0 == index $c->req->url->path, $asset_path;
 }
 
 sub _build_assets_dir {
